import os
import glob
import logging as log


class LatexCreator:
    def __init__(self, template, outdir, source_folder, filename):
        self.template = template
        self.outdir = outdir
        self.source_folder = source_folder
        self.keys = None
        self.filename = filename

        ensure_dirs(dirs=[self.outdir])

    def create_latex_doc(self, filename=None):
        if filename is None:
            filename = self.filename
        create_latex_doc(template=self.template,
                         keys=self.keys,
                         filename=filename,
                         outdir=self.outdir)

    def make_bibliography(self, filename="references.bib"):
        log.info("Creating bibliography of source_folder {}".format(self.source_folder))
        self.keys = make_bibliography(source_folder=self.source_folder,
                                      outdir=self.outdir,
                                      filename=filename)
        log.info("Created bibliography in file {}".format(
            os.path.join(self.outdir, filename)))


def ensure_dirs(dirs):
    for dir in dirs:
        if not os.path.exists(dir):
            os.makedirs(dir)


def make_bibliography(source_folder, outdir, filename="references.bib"):
    keys = []
    files = glob.glob(source_folder + "/*")

    combined_data = ""
    for file in files:
        with open(file, "r") as f:
            data = f.read()
            key = data.split("\n")[0]
            idx = key.find("{")
            key = key[idx+1:-1]
            keys.append(key)
        combined_data += data + "\n"

    file_to_write = os.path.join(outdir, filename)
    with open(file_to_write, "w") as f:
        f.write(combined_data)

    return keys


def create_latex_doc(template, keys, filename, outdir):
    cwd = os.getcwd()
    if not os.path.exists(outdir):
        os.makedirs(outdir)

    os.chdir(outdir)
    nocite_string = ""
    for key in keys:
        nocite_string += r"\nocite{" + key + "}\n"
    this_template = template.replace("__NOCITES__", nocite_string)
    print(this_template)

    with open(filename, "w") as f:
        f.write(this_template)

    # compile template.tex to template.pdf
    os.system(f"pdflatex -interaction=nonstopmode {filename}")
    os.system(
        "bibtex {filename}".format(filename=filename.replace(".tex", "")))
    os.system(f"pdflatex -interaction=nonstopmode {filename}")
    os.system(f"pdflatex -interaction=nonstopmode {filename}")
    os.chdir(cwd)



import datetime
import time
from urllib.parse import quote

import requests
import math
import tqdm
import yaml
import pickle
import pandas as pd
import numpy as np
import os
import re
import json
from itertools import compress


def read_config(file_to_read):
    with open(file_to_read, "r") as f:
        config = yaml.load(f, Loader=yaml.SafeLoader)
    return config


def read_from_inspire(formatted_query, silent=False):
    response = requests.get(formatted_query)
    while response.status_code != 200:
        time.sleep(1.0)
        print("retrieving failed, with status code: " +
              str(response.status_code))
        print("query is:")
        print(formatted_query)
        print("trying again...")

        response = requests.get(formatted_query)
        #  response.raise_for_status()  # raises exception when not a 2xx response
    else:
        data = response.json()
        if not silent:
            print("data retrieved.")
    return data


def get_publication_query(publications, clickable):
    ids = []
    for publication in publications:
        ids.append(publication.id)
    result = get_publication_by_id(id_list=ids)
    if not clickable:
        return result
    else:
        return result.replace("api/", "").replace("fields=titles,authors,id",
                                                  "")


def get_publication_by_id(id_list, size=500):
    other_query = 'https://inspirehep.net/api/literature?fields=titles,authors,id&sort=mostrecent&size={size}&page={page}&q='
    id_template = 'recid%3A{id} or '

    id_query = ""
    for id in id_list:
        id_query += id_template.format(id=id)
    id_query = id_query[:-4]
    id_query = id_query.replace(" ", "%20")
    return other_query.format(page='1', size=size) + id_query


def build_time_query(lower_date=None, upper_date=None):
    time_query_low = 'date>{lower_date}'
    time_query_up = 'date<{upper_date}'
    if upper_date is not None and lower_date is not None:
        return time_query_low.format(
            lower_date=lower_date) + " and " + time_query_up.format(
                upper_date=upper_date)
    elif lower_date is not None:
        return time_query_low.format(lower_date=lower_date)
    else:
        return ""


def build_people_query(file_to_read):
    # This needs to be replaced with the csv from Anja
    with open(file_to_read, "r") as f:
        people_to_match = [line.strip() for line in f]

    author_query = '(author%3A{name})'
    people_query = ""
    for author in people_to_match:
        people_query += author_query.format(name=author) + " or "
    people_query = people_query[:-4]
    people_query = people_query.replace(" ", "%20")
    return people_query, people_to_match


def build_person_query(person, size=25, search_type="authors"):
    if search_type not in ["authors", "literature"]:
        raise ValueError("search_type must be either authors or literature")

    query_template = build_query_template(lower_date=None, upper_date=None, add_institute=False, search_type=search_type) + "&q={person}".format(person=quote(person))
    query_template = query_template.format(size=size, page=1)
    return query_template

def build_query_template(lower_date, upper_date, add_institute=True, search_type="literature"):
    # building query command
    institute_query = 'https://inspirehep.net/api/{search_type}?sort=mostrecent&size={size}&page={page}'
    if add_institute:
        institute_query += "&q=aff:{institute}"
    time_query = build_time_query(lower_date=lower_date, upper_date=upper_date)
    if time_query != "":
        institute_and_time_query = institute_query + " and " + time_query
    else:
        institute_and_time_query = institute_query

    matches = re.findall(r'\{(.*?)\}', institute_and_time_query)
    replace_dict = {}
    for match in matches:
        if match != "search_type":
            replace_dict[match] = "{" + match + "}"
        else:
            replace_dict[match] = search_type
    institute_and_time_query = institute_and_time_query.format(
        **replace_dict)

    institute_and_time_query = institute_and_time_query.replace(" ", "%20")
    institute_and_time_query = institute_and_time_query.replace("\n", "")
    return institute_and_time_query


def get_matched_authors(publications, institute, people_to_exclude):
    all_authors = []
    for pub in publications:
        for auth in pub.author_objects:
            if auth.affiliations is not None and institute in auth.affiliations:
                for name in people_to_exclude:
                    if name in auth.full_name:
                        print("excluding: " + auth.full_name,
                              "with publication", pub.title)
                        break
                else:
                    all_authors.append(auth)

    all_authors_named = list(set([auth.full_name for auth in all_authors]))
    return all_authors_named


def get_data(global_query, retrieve, institute_and_time_query, config):
    if retrieve:
        # retrieving data
        data = read_from_inspire(formatted_query=global_query)
        total_hits = data["hits"]["total"]
        n_pages = int(total_hits / int(config["size"])) + 1
        for i in tqdm.tqdm(range(n_pages)):
            if i > 0:
                time.sleep(1.0)
                this_query = institute_and_time_query.format(
                    page=str(i + 1),
                    size=str(config["size"]),
                    institute=quote(config["institute"]))
                temp_data = read_from_inspire(formatted_query=this_query)
                data["hits"]["hits"] += temp_data["hits"]["hits"]
        data, df = apply_cleaning_to_data(data=data, config=config)
    else:
        data = read_data(filename=config["cache_file"])
        data, df = apply_cleaning_to_data(data=data, config=config)
        total_hits = data["hits"]["total"]
    return data


def read_data(filename):
    print("Reading data...")
    with open(filename, "rb") as f:
        data = pickle.load(f)
    return data


def write_data(filename, data):
    print("Writing data...")
    with open(filename, "wb") as f:
        pickle.dump(data, f)


def get_earliest_date(row):
    if "earliest_date" in row["metadata"]:
        return row["metadata"]["earliest_date"]
    else:
        return None


def apply_cleaning_to_data(data, config):
    df = convert_to_pandas(data)
    if config["lower_date"] is not None:
        masker_low = df["earliest_date"] > config["lower_date"]
    else:
        masker_low = np.array([True] * len(df))

    if config["upper_date"] is not None:
        masker_up = df["earliest_date"] < config["upper_date"]
    else:
        masker_up = np.array([True] * len(df))

    masker = masker_low & masker_up

    filtered_list = list(compress(data["hits"]["hits"], masker))
    data["hits"]["total"] = len(filtered_list)
    data["hits"]["hits"] = filtered_list
    return data, df[masker]


def get_tarball_of_publications(publications, link_type, target_dir, tarball_name):
    if not os.path.exists(target_dir):
        os.makedirs(target_dir)

    ids = []
    for pub in publications:
        link = pub.links[link_type]
        ids.append(pub.id)
        cmd = "wget -P {target_dir} {link}".format(target_dir=target_dir,
                                                   link=link)
        os.system(cmd)
    else:
        print("Downloaded {} publication files".format(len(ids)))

    # Create tarball of all files
    cmd = "tar -czvf {tarball_name} -C {target_dir} .".format(
        tarball_name=tarball_name, target_dir=target_dir)
    os.system(cmd)


def convert_to_pandas(data):
    df = pd.DataFrame(data["hits"]["hits"])
    updated_date = df.apply(lambda row: datetime.datetime.strptime(
        row["updated"], "%Y-%m-%dT%H:%M:%S.%f+00:00"),
                            axis=1)
    created_date = df.apply(
        lambda row: datetime.datetime.strptime(row["created"][:4], "%Y"),
        axis=1)
    df["updated_date"] = pd.to_datetime(updated_date)
    df["created_date"] = pd.to_datetime(created_date)
    earliest_date = df.apply(lambda row: get_earliest_date(row=row), axis=1)
    df["earliest_date"] = pd.to_datetime(earliest_date)
    return df

def match_publications_by_keywords(publications, keywords):
    publications_without_keywords = []
    matched_publications = []
    unmatched_publications = []

    for pub in tqdm.tqdm(publications):
        if pub.keywords is not None:
            for keyword in keywords:
                if keyword in pub.keywords:
                    matched_publications.append(pub)
                    break
            else:
                unmatched_publications.append(pub)
        else:
            publications_without_keywords.append(pub)
            continue
    return publications_without_keywords, matched_publications, unmatched_publications

def match_publications_by_authors(publications, bais_to_check_against, institute):
    matched_publications = []
    unmatched_publications = []

    for pub in publications:
        matched = False
        for author_to_check in bais_to_check_against:
            if author_to_check in pub.author_bais:
                idx = pub.author_bais.index(author_to_check)
                candidate_author = pub.author_objects[idx]
                if candidate_author.affiliations is not None:
                    for affiliation in candidate_author.affiliations:
                        if affiliation == institute:
                            matched_publications.append(pub)
                            matched = True
                            break
            if matched:
                break
        if not matched:
            unmatched_publications.append(pub)
    return matched_publications, unmatched_publications

def get_clickable_links(publications):
    clickable_links = []
    for i in range(math.ceil(len(publications) / 100)):
        print(100 * i, 100 * (i + 1))
        print(len(publications[100 * i:100 * (i + 1)]))

        clickalbe_link = get_publication_query(
            publications[100 * i:100 * (i + 1)], clickable=True)
        clickable_links.append(clickalbe_link)
    return clickable_links

def check_missing_publications_on_disk(publications, target_dir, link_type):
    missing_publications = []
    for pub in publications:
        path_to_check = os.path.join(target_dir, pub.id + "?format={}".format(link_type))
        print(path_to_check)
        if not os.path.exists(path_to_check):
            missing_publications.append(pub)
    return missing_publications

def build_name_proposal_from_excel(path_to_excel):
    df = pd.read_excel(path_to_excel)
    name_proposal_data = []
    for i in range(len(df)):
        data = df.iloc[i]["inspire_names"]
        splitted_data = data.split(";")
        for split in splitted_data:
            name_proposal_data.append(split)
    return name_proposal_data

def get_inspire_bai(file):
    with open(file, "r") as f:
        data = json.load(f)
    l_bais = []
    for idx, item in enumerate(data["hits"]["hits"]):
        if "ids" in item["metadata"]:
            schemas = [id["schema"] for id in item["metadata"]["ids"]]
            if "INSPIRE BAI" not in schemas:
                print("No INSPIRE BAI")
            else:
                idx_scheme = schemas.index("INSPIRE BAI")
                bai = item["metadata"]["ids"][idx_scheme]["value"]
                l_bais.append(bai)
        else:
            print("No ids found")
        if idx > 4:
            break
    return l_bais

def get_inspire_bais_from_filelist(filelist):
    l_bais = []
    for file in filelist:
        l_bais += get_inspire_bai(file)
    return l_bais



"""Top-level package for inspire_info."""

__author__ = """Tim Wolf"""
__email__ = 'tim.wolf@mpi-hd.mpg.de'
__version__ = '0.1.9'

from .myutils import *
from .LatexCreator import *
from .Author import *
from .Publication import *


__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

import glob
import inspire_info



files = glob.glob("authors/*.txt")
files = ["authors/author_Hoetzsch, Luisa.txt"]
for file in files:
    bais_to_check = inspire_info.myutils.get_inspire_bai(file)
    for bai in bais_to_check:
        query = inspire_info.build_person_query(bai, search_type='literature')
        data = inspire_info.read_from_inspire(query, silent=True)




class Author(object):

    def __init__(self, author):
        self.author = author
        self.full_name = author["full_name"]
        self.uuid = author["uuid"]

    @property
    def affiliations(self):
        if "affiliations" in self.author.keys():
            affiliations = [
                affiliation["value"]
                for affiliation in self.author["affiliations"]
            ]
        elif "raw_affiliations" in self.author.keys():
            affiliations = [
                affiliation["value"]
                for affiliation in self.author["raw_affiliations"]
            ]
        else:
            affiliations = None
        return affiliations

    @property
    def bai(self):
        if "ids" in self.author.keys():
            for id in self.author["ids"]:
                if id["schema"] == "INSPIRE BAI":
                    return id["value"]
        return None


    def __repr__(self):
        return "Author(" + self.full_name + ")"



#!/usr/bin/env python

__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

import argparse
import os
from inspire_info import LatexCreator

def parse_args():
    parser = argparse.ArgumentParser(
        description='Command line tool to search for authors in inspire')
    parser.add_argument('--source_dir',
                        type=str,
                        help="Directory where the bibtex-output is stored.",
                        default="bibtex"
                        )
    parser.add_argument('--output_dir',
                        type=str,
                        help="Directory where the latex-output is stored.",
                        required=True
                        )
    parser.add_argument('--filename',
                        type=str,
                        help="Filename of the latex-output.",
                        default="publications.tex"
                        )

    return dict(vars(parser.parse_args()))

template = r"""\documentclass[11pt]{article}

\title{Bibliography}
\author{Tim Wolf}
\date{}

%\usepackage[resetlabels,labeled]{multibib}
% \usepackage{bibtex}
% \newcites{Math}{Math Readings}
% \newcites{Phys}{Physics Readings}


\begin{document}

% \maketitle

__NOCITES__

\bibliographystyle{abbrv}
\bibliography{references}

% \bibliographystyleMath{unsrt}
% \bibliographyMath{refs-etc}

% \bibliographystylePhys{unsrt}
% \bibliographyPhys{refs-etc}

\end{document}
"""

def create_latex_doc(template, output_dir, source_dir, filename):
    document_maker = LatexCreator(template=template,
                                  outdir=output_dir,
                                  source_folder=source_dir,
                                  filename=filename)
    document_maker.make_bibliography()

    document_maker.create_latex_doc()

def main():
    parsed_args = parse_args()
    parsed_args["template"] = template
    create_latex_doc(**parsed_args)


if __name__ == "__main__":
    main()



#!/usr/bin/env python

__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

import inspire_info
import json
import os
import tqdm
import argparse


def parse_args():
    parser = argparse.ArgumentParser(
        description='Command line tool to search for authors in inspire')
    parser.add_argument('--search_name',
                        type=str,
                        help="Name to search for.",
                        default=None
                        )
    parser.add_argument('--custom_name_proposal',
                        type=str,
                        help="Names of the people to search for.",
                        default=None)
    parser.add_argument('--authors_output_dir',
                        type=str,
                        help="Directory to save the output.",
                        default="authors")

    return dict(vars(parser.parse_args()))

def search_authors_and_download(search_name=None, custom_name_proposal=None, authors_output_dir="authors"):
    if search_name is None and custom_name_proposal is None:
        raise ValueError("Please provide a search name or a custom name proposal.")

    if custom_name_proposal is not None:
        with open(custom_name_proposal, "r", encoding='unicode-escape') as f:
            authors = [line.strip() for line in f]
    else:
        authors = [search_name]

    print("Saving authors to directory: {}".format(authors_output_dir))
    if not os.path.exists(authors_output_dir):
        os.makedirs(authors_output_dir)

    print("Searching for authors")
    for author in tqdm.tqdm(authors):
        query = inspire_info.myutils.build_person_query(author, size=5)
        data = inspire_info.myutils.read_from_inspire(query, silent=True)
        path_to_save = os.path.join(authors_output_dir, f"author_{author}.txt")
        with open(path_to_save, "w") as f:
            json.dump(data, f)

def main():
    parsed_args = parse_args()
    search_authors_and_download(**parsed_args)

if __name__ == "__main__":
    main()



__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

from tkinter import W
from inspire_info.InspireInfo import InspireInfo
import sys
import argparse


def parse_args(args):
    parser = argparse.ArgumentParser(
        description='Scraping of inspire for institute publications')
    parser.add_argument('--retrieve',
                        action='store_true',
                        help="""If added API-call is created, otherwise 
            cache-file is going to be used.""")
    parser.add_argument(
        '--get_links',
        action='store_true',
        help="Prints the inspire quieries to the found publications")
    parser.add_argument('--get_name_proposal',
                        action='store_true',
                        help="Write out name_proposal.txt")
    parser.add_argument('--create_cache',
                        action='store_true',
                        help="Create the cache-file")
    parser.add_argument('--config',
                        type=str,
                        help="Config file to read.",
                        required=True)

    return dict(vars(parser.parse_args(args)))


def main(arguments):
    parsed_args = parse_args(args=arguments)

    inspire_getter = InspireInfo(config_path=parsed_args["config"])
    inspire_getter.get_data(retrieve=parsed_args["retrieve"])
    _, matched_publications, _ = inspire_getter.match_publications_by_keywords(
    )
    all_authors_from_institution_named = inspire_getter.match_authors(
        matched_publications)
    inspire_getter.name_proposal_data = all_authors_from_institution_named
    inspire_getter.write_name_proposal()

    if parsed_args["get_links"]:
        inspire_getter.print_links(match_type="matched")


if __name__ == "__main__":
    main(sys.argv[1:])



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

with open("requirements.txt") as f:
    requirements = f.read().splitlines()

test_requirements = ['pytest>=3', ]

setup(
    author="Tim Wolf",
    author_email='tim.wolf@mpi-hd.mpg.de',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.9',
    ],
    description="Package to retrieve more complex info from inspire than the web-interface allows",
    entry_points={
        'console_scripts': [
            'ii_get_papers=inspire_info.scripts.get_papers:main',
            'ii_create_cache_file=inspire_info.scripts.create_cache_file:main',
            'ii_search_authors_and_download=inspire_info.scripts.search_authors_and_download:main',
            'ii_create_latex_doc=inspire_info.scripts.create_latex_doc:main',
            'ii_merge_bibtex_files=inspire_info.scripts.merge_bibtex_files:main',
            'ii_create_publication_history=inspire_info.scripts.create_publication_history:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='inspire_info',
    name='inspire_info',
    packages=find_packages(include=['inspire_info', 'inspire_info.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/WolfXeHD/inspire_info',
    version='0.1.9',
    zip_safe=False,
)



#!/usr/bin/env python

__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

import argparse
from inspire_info.InspireInfo import InspireInfo


def parse_args():
    parser = argparse.ArgumentParser(
        description='Scraping of inspire for institute publications')
    parser.add_argument('--config',
                        type=str,
                        help="Config file to read.",
                        required=True)

    return dict(vars(parser.parse_args()))


def main():
    parsed_args = parse_args()
    inspire_getter = InspireInfo(config_path=parsed_args["config"])
    inspire_getter.get_data(retrieve=True)
    inspire_getter.write_data()

if __name__ == "__main__":
    main()



#!/usr/bin/env python

__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

import glob
import argparse

def parse_args():
    parser = argparse.ArgumentParser(
        description='Merge bibtex files into one file')
    parser.add_argument('--source_dir',
                        type=str,
                        help="Directory where the bibtex-output is stored.",
                        required=True
                        )
    parser.add_argument('--output_file',
                        type=str,
                        help="File to save the output.",
                        required=True
                        )

    return dict(vars(parser.parse_args()))

def main():
    parsed_args = parse_args()
    files_query = parsed_args["source_dir"] + "/*"
    files = glob.glob(files_query)

    total_data = ""
    for file in files:
        with open(file, "r") as f:
            data = f.read()
        total_data += "\n\n"
        total_data += data

    with open(parsed_args["output_file"], "w") as f:
        f.write(total_data)
    print("{} files merged into {}".format(len(files), parsed_args["output_file"]))



#!/usr/bin/env python

__author__ = 'Tim Michael Heinz Wolf'
__version__ = '0.1.9'
__license__ = 'MIT'
__email__ = 'tim.wolf@mpi-hd.mpg.de'

import argparse
from datetime import datetime
from inspire_info.InspireInfo import InspireInfo
from inspire_info.scripts.create_latex_doc import template as latex_template
from inspire_info.scripts.create_latex_doc import create_latex_doc
from inspire_info.scripts.search_authors_and_download import search_authors_and_download
from inspire_info.scripts.get_papers import get_papers

def parse_args():
    parser = argparse.ArgumentParser(
        description='Scraping of inspire for institute publications')
    parser.add_argument('--config',
                        type=str,
                        help="Config file to read.",
                        required=True)
    parser.add_argument('--authors_output_dir',
                        type=str,
                        help="Directory to save the output.",
                        default="authors")
    parser.add_argument('--update_authors',
                        action="store_true",
                        help="Update authors in the authors_output_dir.")
    parser.add_argument('--retrieve_data',
                        action="store_true",
                        help="Executes the download of the cache-file.")
    parser.add_argument('--custom_name_proposal',
                        type=str,
                        help="Custom name proposal for the file to be used.",
                        default=None)
    parser.add_argument('--year',
                        type=int,
                        help="Year to be used for the latex file.",
                        default=None)

    return dict(vars(parser.parse_args()))

def main():
    parsed_args = parse_args()
    inspire_getter = InspireInfo(parsed_args["config"])
    if parsed_args["retrieve_data"]:
        inspire_getter.get_data(retrieve=True)
        inspire_getter.write_data()

    if inspire_getter.cache_exists:
        inspire_getter.get_data(retrieve=False)
    else:
        inspire_getter.get_data(retrieve=True)
        inspire_getter.write_data()
    print(f"Data retrieved: {inspire_getter.has_data}")


    if parsed_args["update_authors"]:
        dict_to_parse = {"custom_name_proposal": parsed_args["custom_name_proposal"],
                            "authors_output_dir": parsed_args["authors_output_dir"],
                            "search_name": None
        }
        search_authors_and_download(**dict_to_parse)

    lower_date = inspire_getter.config["lower_date"]
    upper_date = inspire_getter.config["upper_date"]

    # parse a string to a date object
    if lower_date is not None:
        lower_date = datetime.strptime(lower_date, "%Y-%m-%d")
    else:
        # set a default value
        lower_date = datetime.strptime("2006-01-01", "%Y-%m-%d")
    if upper_date is not None:
        upper_date = datetime.strptime(upper_date, "%Y-%m-%d")
    else:
        # set a default value
        upper_date = datetime.now()
    print(f"Lower date: {lower_date}, upper date: {upper_date}")

    #make list of years between two dates
    years = [lower_date.year + i for i in range(upper_date.year - lower_date.year + 2)]
    if parsed_args["year"] is not None:
        years = [parsed_args["year"], parsed_args["year"] + 1]

    l_bibtex_folders = []
    for lower_year, upper_year in zip(years, years[1:]):
        lower_date = '{lower_year}-01-01'.format(lower_year=lower_year)
        upper_date = '{upper_year}-01-01'.format(upper_year=upper_year)


        target_dir = "publications_{lower_year}".format(lower_year=lower_year)
        dict_to_parse = {"config": parsed_args["config"],
                        "lower_date": lower_date,
                        "upper_date": upper_date,
                        "authors_output_dir": parsed_args["authors_output_dir"],
                        "download": "bibtex",
                        "target_dir": target_dir}
        l_bibtex_folders.append(target_dir)
        get_papers(**dict_to_parse)

        out_dir = "latex_{target_dir}".format(target_dir=target_dir)
        create_latex_doc(latex_template, out_dir, target_dir, filename=f"publications_{lower_year}.tex")

if __name__ == "__main__":
    main()
